#' @details
#' rbedrock is currently under development.
#' @keywords internal
#' @import rlang
"_PACKAGE"

# The following block is used by usethis to automatically manage
# roxygen namespace tags. Modify with care!
## usethis namespace: start
#' @importFrom R6 R6Class
## usethis namespace: end
NULL
